IF OBJECT_ID('[DashboardPackages_Latest]') IS NOT NULL DROP VIEW [DashboardPackages_Latest]
GO

CREATE VIEW [DashboardPackages_Latest]
AS
	SELECT * FROM
	(SELECT TOP 10 NP.[Feed_Id],
	              F.[Feed_Name],
				  NP.[Package_Id],
				  NPV.[Version_Text],
				  NPV.[Published_Date],
				  F.[FeedType_Name],
            [Group_Id] = NULL
	  FROM [NuGetPackageVersionsV2] NPV
	       INNER JOIN [NuGetPackagesV2] NP
		           ON NP.[NuGetPackageV2_Id] = NPV.[NuGetPackageV2_Id]
	       INNER JOIN [Feeds] F
		           ON F.[Feed_Id] = NP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND NPV.[Cached_Indicator] = 'N'
	 ORDER BY NPV.[Published_Date] DESC) A

	UNION ALL
	SELECT * FROM
	(SELECT TOP 10 P.[Feed_Id],
	              F.[Feed_Name],
				  P.[Package_Id],
				  P.[Version_Text],
				  P.[Published_Date],
				  F.[FeedType_Name],
            [Group_Id] = NULL
	  FROM [NuGetPackages] P
	       INNER JOIN [Feeds] F
		           ON F.[Feed_Id] = P.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND P.[Cached_Indicator] = 'N'
	 ORDER BY P.[Published_Date] DESC) A

	UNION ALL
	SELECT * FROM

	(SELECT TOP 10 NP.[Feed_Id],
	              F.[Feed_Name],
				  [Package_Id] = CASE WHEN NP.[Scope_Name] = '' THEN NP.[Package_Name] ELSE '@' + NP.[Scope_Name] + '/' + NP.[Package_Name] END,
				  NPV.[Version_Text],
				  NPV.[Published_Date],
				  F.[FeedType_Name],
            [Group_Id] = NULL
		  FROM [NpmPackageVersions] NPV
		       INNER JOIN [NpmPackages] NP
			           ON NP.[Package_Id] = NPV.[Package_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = NP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
       AND NPV.[Cached_Indicator] = 'N'
	 ORDER BY NPV.[Published_Date] DESC) B


	UNION ALL
	SELECT * FROM

	(SELECT TOP 10 MA.[Feed_Id],
	              F.[Feed_Name],
				  [Package_Id] = MA.[ArtifactId_Text],
				  MAF.[Version_Text],
				  MAF.[Updated_Date],
				  F.[FeedType_Name],
            [Group_Id] = MA.[GroupId_Text]
		  FROM [MavenArtifacts] MA
		       INNER JOIN [MavenArtifactFiles] MAF
			           ON MAF.[MavenArtifact_Id] = MA.[MavenArtifact_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = MA.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND MAF.[File_Type] = '.pom'
       AND MAF.[Cached_Indicator] = 'N'
	 ORDER BY MAF.[Updated_Date] DESC) C

	UNION ALL
	SELECT * FROM

	(SELECT TOP 10 F.[Feed_Id],
	              F.[Feed_Name],
				  [Package_Id] = PGP.[Package_Name],
				  PGPV.[Version_Text],
				  PGPV.[Published_Date],
				  F.[FeedType_Name],
            [Group_Id] = PGP.[Group_Name]
		  FROM [ProGetPackageVersions] PGPV
		       INNER JOIN [ProGetPackages] PGP
			           ON PGP.[ProGetPackage_Id] = PGPV.[ProGetPackage_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = PGP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
       AND PGPV.[Cached_Indicator] = 'N'
	 ORDER BY PGPV.[Published_Date] DESC) D

	UNION ALL
	SELECT * FROM

	(SELECT TOP 10 F.[Feed_Id],
	              F.[Feed_Name],
				  [Package_Id] = DI.[Repository_Name],
				  [Version_Text] = DIT.[Tag_Name],
				  DI.[Published_Date],
				  F.[FeedType_Name],
            [Group_Id] = NULL
		  FROM [DockerImages] DI
		       INNER JOIN [DockerImageTags] DIT
			           ON DIT.[Feed_Id] = DI.[Feed_Id]
					  AND DIT.[Image_Digest] = DI.[Image_Digest]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = DI.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	 ORDER BY DI.[Published_Date] DESC) E

	UNION ALL
	SELECT * FROM

	(SELECT TOP 10 F.[Feed_Id],
	              F.[Feed_Name],
				  [Package_Id] = RG.[Gem_Name],
				  RGV.[Version_Text],
				  RGV.[Published_Date],
				  F.[FeedType_Name],
            [Group_Id] = NULL
		  FROM [RubyGemVersions] RGV
		       INNER JOIN [RubyGems] RG
			           ON RG.[Gem_Id] = RGV.[Gem_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = RG.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
       AND RGV.[Cached_Indicator] = 'N'
	 ORDER BY RGV.[Published_Date] DESC) E

	UNION ALL
	SELECT * FROM
	(SELECT TOP 10 VP.[Feed_Id],
	              F.[Feed_Name],
				  VP.[Package_Id],
				  [Version_Text] = CAST(VP.[Major_Number] AS VARCHAR(50)) + '.' + CAST(VP.[Minor_Number] AS VARCHAR(50)) + '.' + CAST(VP.[Build_Number] AS VARCHAR(50)) + '.' + CAST(VP.[Revision_Number] AS VARCHAR(50)),
				  VP.[Published_Date],
				  F.[FeedType_Name],
            [Group_Id] = NULL
	  FROM [VsixPackages] VP
	       INNER JOIN [Feeds] F
		           ON F.[Feed_Id] = VP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND VP.[Cached_Indicator] = 'N'
	 ORDER BY VP.[Published_Date] DESC) F

GO