EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'MavenArtifacts_DeleteArtifact',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes a Maven artifact file.'
GO

IF OBJECT_ID('[MavenArtifacts_DeleteArtifact]') IS NOT NULL DROP PROCEDURE [MavenArtifacts_DeleteArtifact]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [MavenArtifacts_DeleteArtifact]
(
	@Feed_Id INT,
	@GroupId_Text NVARCHAR(200),
	@ArtifactId_Text NVARCHAR(100),
	@Version_Text NVARCHAR(50) = NULL,
	@File_Type NVARCHAR(50) = NULL,
	@LatestVersion_Text NVARCHAR(50) = NULL
)
AS
BEGIN

SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @MavenArtifact_Id INT
	SET @MavenArtifact_Id = (SELECT [MavenArtifact_Id]
	                           FROM [MavenArtifacts]
							  WHERE [Feed_Id] = @Feed_Id
	                            AND [GroupId_Text] = @GroupId_Text
	                            AND [ArtifactId_Text] = @ArtifactId_Text)

	DELETE [MavenArtifactFiles]
	 WHERE [MavenArtifact_Id] = @MavenArtifact_Id
	   AND (@File_Type IS NULL OR [File_Type] = @File_Type)
	   AND (@Version_Text IS NULL OR [Version_Text] = @Version_Text)

	IF NOT EXISTS(SELECT * FROM [MavenArtifactFiles] WHERE [MavenArtifact_Id] = @MavenArtifact_Id)
	BEGIN

		DELETE [MavenArtifacts]
		 WHERE [MavenArtifact_Id] = @MavenArtifact_Id

	END
	ELSE
	BEGIN

		UPDATE MA
		   SET MA.[ReleaseVersion_Text] = CASE WHEN EXISTS(SELECT * FROM [MavenArtifactFiles] MAF WHERE MAF.[MavenArtifact_Id] = MA.[MavenArtifact_Id] AND MAF.[Version_Text] = MA.[ReleaseVersion_Text]) THEN [ReleaseVersion_Text] ELSE NULL END,
		       MA.[LatestVersion_Text] = @LatestVersion_Text
		  FROM [MavenArtifacts] MA
		 WHERE MA.[MavenArtifact_Id] = @MavenArtifact_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [MavenArtifacts_DeleteArtifact] TO [ProGetUser_Role]